@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
-our $DATE = '2016-08-11'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-08-23'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -133,7 +133,7 @@ sub detect_perinci_cmdline_script {
         #    (Perinci::CmdLine(|::Any|::Lite|::Classic))/mx) {
 
         for (split /^/, $str) {
-            if (/^\s*use\s+(Perinci::CmdLine(|::Any|::Lite|::Classic))\b/) {
+            if (/^\s*(use|require)\s+(Perinci::CmdLine(|::Any|::Lite|::Classic))\b/) {
                 $yesno = 1;
                 $meta->{'func.module'} = $2;
                 last DETECT;
@@ -201,7 +201,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.10 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2016-08-11.
+This document describes version 0.11 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2016-08-23.
 
 =head1 SYNOPSIS
 
